@@ -1,14 +1,14 @@
 package Lingua::GA::Gramadoir::Languages::ro;
-# Mesajele n limba romn pentru pachetul gramadoir.
+# Mesajele în limba română pentru pachetul gramadoir.
 # Copyright (C) 2003 Free Software Foundation, Inc.
-# Acest fiier este distribuit sub aceeai licen ca pachetul gramadoir.
+# Acest fişier este distribuit sub aceeaşi licenţă ca pachetul gramadoir.
 # Eugen Hoanca <eugenh@urban-grafx.ro>, 2003.
 #
 #msgid ""
 #msgstr ""
 #"Project-Id-Version: gramadoir 0.3\n"
-#"Report-Msgid-Bugs-To: <scannell@slu.edu>\n"
-#"POT-Creation-Date: 2005-03-02 22:40-0600\n"
+#"Report-Msgid-Bugs-To: <kscanne@gmail.com>\n"
+#"POT-Creation-Date: 2008-09-05 17:20-0500\n"
 #"PO-Revision-Date: 2003-10-28 12:23+0200\n"
 #"Last-Translator: Eugen Hoanca <eugenh@urban-grafx.ro>\n"
 #"Language-Team: Romanian <translation-team-ro@lists.sourceforge.net>\n"
@@ -155,8 +155,8 @@ use vars qw(%Lexicon);
     "[_1]: unrecognized error macro: [_2]\n"
  => "opţiune necunoscută [_1].",
 
-    "Valid word but extremely rare in actual usage"
- => "Valid word but extremely rare in actual usage",
+    "Valid word but extremely rare in actual usage. Is this the word you want?"
+ => "Valid word but extremely rare in actual usage. Is this the word you want?",
 
     "Repeated word"
  => "Repeated word",
@@ -170,6 +170,9 @@ use vars qw(%Lexicon);
     "The singular form is required here"
  => "The singular form is required here",
 
+    "Plural adjective required"
+ => "Plural adjective required",
+
     "Comparative adjective required"
  => "Comparative adjective required",
 
@@ -179,12 +182,21 @@ use vars qw(%Lexicon);
     "Unnecessary use of the definite article"
  => "Unnecessary use of the definite article",
 
+    "No need for the first definite article"
+ => "No need for the first definite article",
+
     "Unnecessary use of the genitive case"
  => "Indulgenţă(lenition) nenecesară",
 
     "The genitive case is required here"
  => "The genitive case is required here",
 
+    "You should use the present tense here"
+ => "Ar trebui să folosiţi mai bine /[_1]/ aici",
+
+    "You should use the conditional here"
+ => "Ar trebui să folosiţi mai bine /[_1]/ aici",
+
     "It seems unlikely that you intended to use the subjunctive here"
  => "It seems unlikely that you intended to use the subjunctive here",
 
@@ -209,8 +221,8 @@ use vars qw(%Lexicon);
     "Unknown word: /[_1]/?"
  => "Cuvânt necunoscut",
 
-    "Valid word but more often found in place of /[_1]/"
- => "Valid word but more often found in place of /[_1]/",
+    "Valid word but /[_1]/ is more common"
+ => "Valid word but /[_1]/ is more common",
 
     "Not in database but apparently formed from the root /[_1]/"
  => "Not in database but apparently formed from the root /[_1]/",
@@ -233,6 +245,15 @@ use vars qw(%Lexicon);
     "Possibly a foreign word (the sequence /[_1]/ is highly improbable)"
  => "Possibly a foreign word (the sequence /[_1]/ is highly improbable)",
 
+    "Gender disagreement"
+ => "Gender disagreement",
+
+    "Number disagreement"
+ => "Number disagreement",
+
+    "Case disagreement"
+ => "Case disagreement",
+
     "Prefix /h/ missing"
  => "Lipseşte prefixul /h/",
 
@@ -251,6 +272,9 @@ use vars qw(%Lexicon);
     "Unnecessary prefix /d'/"
  => "Indulgenţă(lenition) nenecesară",
 
+    "Unnecessary prefix /b'/"
+ => "Indulgenţă(lenition) nenecesară",
+
     "Unnecessary initial mutation"
  => "Indulgenţă(lenition) nenecesară",
 
@@ -260,6 +284,9 @@ use vars qw(%Lexicon);
     "Unnecessary lenition"
  => "Indulgenţă(lenition) nenecesară",
 
+    "The second lenition is unnecessary"
+ => "The second lenition is unnecessary",
+
     "Often the preposition /[_1]/ causes lenition, but this case is unclear"
  => "Often the preposition /[_1]/ causes lenition, but this case is unclear",
 
@@ -299,5 +326,26 @@ use vars qw(%Lexicon);
     "Fifth (mixed) mutation after 'th missing"
  => "Mutaţie iniţială lipsă",
 
+    "Aspirate mutation missing"
+ => "Mutaţie iniţială lipsă",
+
+    "This word violates the rules of Igbo vowel harmony"
+ => "This word violates the rules of Igbo vowel harmony",
+
+    "#~ \"    --teanga=XX    specify the language of the text to be checked \"#~ \"(default=ga)\""
+ => "#~ \"    --teanga=XX    specifică limba textului care urmează a fi verificat\"#~ \"(implicit=ga)\"",
+
+    "Unknown word (ignoring remainder in this sentence)"
+ => "#~ \"Cuvânt necunoscut (se ignoră marcajul(remainder) în această propoziţie)\"",
+
+    "[_1]: out of memory\n"
+ => "[_1]: Memorie plină\n",
+
+    "[_1]: warning: check size of [_2]: %d?\n"
+ => "[_1]: avertisment: verificaţi mărimea lui [_2]: %d?\n",
+
+    "problem with the `cuardach' command\n"
+ => "problemă cu comanda `cuardach'\n",
+
 );
 1;
